@@ -5,7 +5,7 @@ from .utils import get_user_name, welcome, load_game, number_to_game ,is_digit
 from .wog_abs import WoG
 from .MemoryGame import MemoryGame
 from .GuessGame import GuessGame
-from .CurrencyRGame import CurrencyRGame
+#from .CurrencyRGame import CurrencyRGame
 #from .currency_converter import CurrencyConverter
 #__all__ = ['get_user_name', 'Factory', 'GuessGame', 'mainGame',
 #           'MemoryGame', 'utils', 'wog_abs']
